#include <bits/stdc++.h>

typedef long long ll;
using namespace std;
#define PYMOD(A, M) ((((A) % (M)) + (M)) % (M))

const int hm1 = 1e9 + 7;
const int hm2 = 999999937;
const int hp1 = 179;
const int hp2 = 239;

template<int hp, int hm>
struct hashed_string {
    vector<int> h;
    vector<int> pp;

    hashed_string(const string& t) {
        h.resize(t.size() + 1);
        pp.resize(t.size() + 1);
        h[0] = 0;
        pp[0] = 1;
        for (int i = 0; i < (int)t.size(); i++) {
            h[i + 1] = PYMOD(1ll * h[i] * hp + (t[i] - 'a' + 1), hm);
            pp[i + 1] = PYMOD(1ll * pp[i] * hp, hm);
        }
    }
    
    //[l; r)
    int substr_hash(int l, int r) {
        return PYMOD(h[r] - 1ll * h[l] * pp[r - l], hm);
    }
};

struct double_hash {
    hashed_string<hp1, hm1> h1;
    hashed_string<hp2, hm2> h2;
    
    double_hash(string s) : h1(s), h2(s) {}

    ll substr_hash(int l, int r) {
        ll p1 = h1.substr_hash(l, r);
        ll p2 = h2.substr_hash(l, r);
        return p1 * hm2 + p2;
    }
};

int minimal_period(const string& s) {
    double_hash h(s);
    for (int k = 1; k <= (int)s.size(); k++) {
        if (s.size() % k == 0) {
            if (h.substr_hash(0, s.size() - k) == h.substr_hash(k, s.size()))
                return k;
        }
    }
    return s.size();
}

ll solve_dumb(const string& s) {
    double_hash h(s);
    ll ans = 0;
    for (int k = 1; k <= (int)s.size(); k++) {
        unordered_set<ll> hh;
        for (int i = 0; i + k <= (int)s.size(); i++) {
            hh.insert(h.substr_hash(i, i + k));    
        }                                        
        ans += hh.size();
    }
    return ans;
}

ll solve(string s, int n) {
    s = s.substr(0, minimal_period(s));
    int k = s.size();
    
    if (2 * k >= n) {
        return solve_dumb(s + s.substr(0, n - k));
    }

    double_hash h(s + s);

    ll ans = 0;
    unordered_set<ll> hh;
    for (int l = 1; l <= (int)s.size(); l++) {
        for (int i = 0; i + l <= (int)s.size(); i++) {
            hh.insert(h.substr_hash(i, i + l));    
        }
    }
    for (int pfx = 1; pfx < k; pfx++) {
        for (int sfx = 1; pfx + sfx <= k; sfx++) {
            hh.insert(h.substr_hash(k - sfx, k + pfx));     
        }
    }
    ans = hh.size();

    for (int pfx = 0; pfx < k; pfx++) {
        for (int sfx = 0; sfx < k; sfx++) {
            if ((sfx == 0 && pfx != 0) || pfx + sfx > k) {
                if (pfx <= n % k)
                    ans += n / k;
                else
                    ans += n / k - 1;
            } else {
                if (pfx <= n % k)
                    ans += n / k - 1;
                else
                    ans += n / k - 2;
            }
        }
    }
   
    return ans;
}

ll solve_dumb(string s, int n) {
    string t;
    for (int i = 0; i < n; i++)
        t.push_back(s[i % s.size()]);
    return solve_dumb(t);
}

mt19937 rnd;

string rstring() {
    uniform_int_distribution<int> len(1, 10);
    uniform_int_distribution<char> symb('a', 'z');
    int n = len(rnd);
    string s;
    for (int i = 0; i < n; i++) {
        s.push_back(symb(rnd));
    }
    return s;
}

bool one_stress() {                             
    string s = rstring();
    uniform_int_distribution<int> ndist(2 * s.size() + 1, 100); 
    int n = ndist(rnd);
    ll ans1 = solve(s, n);
    ll ans2 = solve_dumb(s, n);
    cout << s << " " << n << " " << ans1 << " " << ans2 << endl;
    return ans1 == ans2;
}

int main() {

    string s;
    int n;
    cin >> s >> n;
    cout << solve(s, n) << endl;
    //cout << solve_dumb(s, n) << endl;
    
    //while (one_stress()) {}
    return 0;
}
